.. redirect-from:: /users/prev_whats_new/github_stats_3.7.0

.. _github-stats-3-7-0:

GitHub statistics for 3.7.0 (Feb 13, 2023)
==========================================

GitHub statistics for 2022/09/16 (tag: v3.6.0) - 2023/02/13

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 120 issues and merged 427 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/70?closed=1>`__

The following 112 authors contributed 1962 commits.

* Abhijnan Bajpai
* Adrien F. Vincent
* Ahoy Ahoy
* Akshit Tyagi
* Ali Meshkat
* Almar Klein
* Andrés Martínez
* Ante Sikic
* Antony Lee
* Augustin LAVILLE
* baharev
* cargobuild
* Carsten Schnober
* Chahak Mehta
* Charisma Kausar
* David Stansby
* dependabot[bot]
* DerWeh
* Eero Vaher
* Elliott Sales de Andrade
* Eric Larson
* Eric Prestat
* erykoff
* EunHo Lee
* Felix Goudreault
* Greg Lucas
* hannah
* Ian Hunt-Isaak
* Ian Thomas
* intellizEHL
* iofall
* j1642
* jacoverster
* Jae-Joon Lee
* Jakub Klus
* James Braza
* Jay Stanley
* Jef Myers
* jeffreypaul15
* Jefro
* Jody Klymak
* John Paul Jepko
* Joseph Fox-Rabinovitz
* Joshua Barrass
* Julian Chen
* Junaid Khan
* Justin Tracey
* Kaidong Hu
* Kanza
* Karan
* Kian Eliasi
* kolibril13
* Kostya Farber
* Krutarth Patel
* Kyle Sunden
* Leo Singer
* Lucas Ricci
* luke
* Marc Van den Bossche
* Martok
* Marvvxi
* Matthew Feickert
* Mauricio Collares
* MeeseeksMachine
* melissawm
* Mikhail Ryazanov
* Muhammad Abdur Rakib
* noatamir
* NRaudseps
* Olivier Castany
* Oscar Gustafsson
* parthpankajtiwary
* Paul Seyfert
* Pavel Grunt
* Pieter Eendebak
* PIotr Strzelczyk
* Pratim Ugale
* pre-commit-ci[bot]
* ramvikrams
* richardsheridan
* Ruth Comer
* Ryan May
* saranti
* Scott Shambaugh
* Shabnam Sadegh
* Shawn Zhong
* Simon Waldherr
* Skhaki18
* slackline
* Snipeur060
* Sourajita Dewasi
* SourajitaDewasi
* Stefanie Molin
* Steffen Rehberg
* Sven Eschlbeck
* sveneschlbeck
* takimata
* tfpf
* Thomas A Caswell
* Tiger Nie
* Tim Hoffmann
* Tom
* Tortar
* tsumli
* tybeller
* vdbma
* Vishal Pankaj Chandratreya
* vivekvedant
* whyvra
* yuanx749
* zhizheng1
* مهدي شينون (Mehdi Chinoune)

GitHub issues and pull requests:

Pull Requests (427):

* :ghpull:`25201`: Backport PR #25196 on branch v3.7.x (Add deprecation for setting data with non sequence type in ``Line2D``)
* :ghpull:`25196`: Add deprecation for setting data with non sequence type in ``Line2D``
* :ghpull:`25197`: Backport PR #25193 on branch v3.7.x (Fix displacement of colorbar for eps with bbox_inches='tight')
* :ghpull:`25193`: Fix displacement of colorbar for eps with bbox_inches='tight'
* :ghpull:`24781`: DOC: restore SHA to footer
* :ghpull:`25188`: Backport PR #25085 on branch v3.7.x (FIX: only try to update blit caches if the canvas we expect)
* :ghpull:`25170`: Backport PR #25097 on branch v3.7.x (fix FigureCanvasTkAgg memory leak via weakrefs)
* :ghpull:`25186`: Backport PR #24893 on branch v3.7.x (STY: make allowed line length 9 longer to 88 from 79)
* :ghpull:`25185`: Backport PR #25183 on branch v3.7.x (FIX: do not use deprecated API internally)
* :ghpull:`25184`: Backport PR #25174 on branch v3.7.x (Accept LA icons for the toolbar)
* :ghpull:`25085`: FIX: only try to update blit caches if the canvas we expect
* :ghpull:`25183`: FIX: do not use deprecated API internally
* :ghpull:`25182`: Backport PR #25052 on branch v3.7.x (Support both Bbox and list for bbox to table/Table)
* :ghpull:`25174`: Accept LA icons for the toolbar
* :ghpull:`25052`: Support both Bbox and list for bbox to table/Table
* :ghpull:`25095`: Backport PR #23442 on branch v3.7.x (Remove need to detect math mode in pgf strings)
* :ghpull:`25097`: fix FigureCanvasTkAgg memory leak via weakrefs
* :ghpull:`25167`: Backport PR #25122 on branch v3.7.x (FIX: scaling factor for window with negative value)
* :ghpull:`25122`: FIX: scaling factor for window with negative value
* :ghpull:`25161`: Backport PR #25158 on branch v3.7.x (Disconnect SubplotTool destroyer callback on tool_fig close)
* :ghpull:`25160`: Backport PR #25129 on branch v3.7.x (Undeprecate Cursor event handlers)
* :ghpull:`25158`: Disconnect SubplotTool destroyer callback on tool_fig close
* :ghpull:`25129`: Undeprecate Cursor event handlers
* :ghpull:`25154`: Backport PR #25151 on branch v3.7.x (Increase timeout to GitHub API)
* :ghpull:`25151`: Increase timeout to GitHub API
* :ghpull:`25136`: Backport PR #25126 on branch v3.7.x (FIX: fully invalidate TransformWrapper parents before swapping)
* :ghpull:`25132`: Backport PR #24993 on branch v3.7.x ([DOC] GitHub spelling and links)
* :ghpull:`25126`: FIX: fully invalidate TransformWrapper parents before swapping
* :ghpull:`24993`: [DOC] GitHub spelling and links
* :ghpull:`25118`: Backport PR #25113 on branch v3.7.x (Fix outdated comment re: _update_label_position.)
* :ghpull:`25113`: Fix outdated comment re: _update_label_position.
* :ghpull:`25111`: Backport PR #25110 on branch v3.7.x (Stop recommending ``ncol`` in legend examples)
* :ghpull:`25110`: Stop recommending ``ncol`` in legend examples
* :ghpull:`25106`: Fix cursor_demo wrt. Line2D.set_x/ydata not accepting scalars anymore.
* :ghpull:`25103`: Backport PR #25098 on branch v3.7.x (Correctly pass valinit as keyword in SliderTool.)
* :ghpull:`25098`: Correctly pass valinit as keyword in SliderTool.
* :ghpull:`23442`: Remove need to detect math mode in pgf strings
* :ghpull:`25093`: Backport PR #25092 on branch v3.7.x (Fix distribution of test data)
* :ghpull:`24893`: STY: make allowed line length 9 longer to 88 from 79
* :ghpull:`25092`: Fix distribution of test data
* :ghpull:`25089`: Backport PR #25088 on branch v3.7.x (DOC: Fix broken cross-reference when building PDF)
* :ghpull:`25088`: DOC: Fix broken cross-reference when building PDF
* :ghpull:`25083`: Backport PR #25074 on branch v3.7.x (Revert "Use system distutils instead of the setuptools copy")
* :ghpull:`25082`: Backport PR #25079 on branch v3.7.x (FIX: Only send one update signal when autoscaling norms)
* :ghpull:`25084`: DOC: Fix typos in GitHub stats
* :ghpull:`25074`: Revert "Use system distutils instead of the setuptools copy"
* :ghpull:`25079`: FIX: Only send one update signal when autoscaling norms
* :ghpull:`25072`: Merge v3.6.x into v3.7.x
* :ghpull:`25071`: Backport PR #25039 on branch v3.7.x (Updated WebAgg JS to check and send request over wss if using HTTPS)
* :ghpull:`25039`: Updated WebAgg JS to check and send request over wss if using HTTPS
* :ghpull:`25070`: Backport PR #25058 on branch v3.7.x (fix for pcolormesh doesn't allow shading = 'flat' in the option)
* :ghpull:`25058`: fix for pcolormesh doesn't allow shading = 'flat' in the option
* :ghpull:`25067`: Backport PR #25054 on branch v3.7.x (Remove note that mathtext.fontset = "custom" is unsupported.)
* :ghpull:`25066`: Backport PR #24999 on branch v3.7.x (DOC: figure explanation)
* :ghpull:`25054`: Remove note that mathtext.fontset = "custom" is unsupported.
* :ghpull:`25065`: Backport PR #24838 on branch v3.7.x (Add styling support to Check and Radio buttons )
* :ghpull:`24999`: DOC: figure explanation
* :ghpull:`24838`: Add styling support to Check and Radio buttons
* :ghpull:`25056`: Backport PR #25055 on branch v3.7.x (Reword awkward sentence in FAQ.)
* :ghpull:`25055`: Reword awkward sentence in FAQ.
* :ghpull:`25049`: Backport PR #25047 on branch v3.7.x (Remove dead code from deprecated-and-removed block)
* :ghpull:`25047`: Remove dead code from deprecated-and-removed block
* :ghpull:`25037`: Backport PR #25018 on branch v3.7.x (Simplify "artist reference" example.)
* :ghpull:`25018`: Simplify "artist reference" example.
* :ghpull:`25034`: Backport PR #24812 on branch v3.7.x ([Doc] expanded basic pie example)
* :ghpull:`24812`: [Doc] expanded basic pie example
* :ghpull:`25029`: Backport PR #25019 on branch v3.7.x (Tweak titles pyplot examples.)
* :ghpull:`25019`: Tweak titles pyplot examples.
* :ghpull:`25026`: Backport PR #25017 on branch v3.7.x (Capitalize headings in example Gallery)
* :ghpull:`25017`: Capitalize headings in example Gallery
* :ghpull:`25010`: Backport PR #24989 on branch v3.7.x (Suppress pyparsing warning)
* :ghpull:`25008`: Backport PR #25004 on branch v3.7.x (Bump pypa/cibuildwheel from 2.11.4 to 2.12.0)
* :ghpull:`24989`: Suppress pyparsing warning
* :ghpull:`25004`: Bump pypa/cibuildwheel from 2.11.4 to 2.12.0
* :ghpull:`25001`: Backport PR #25000 on branch v3.7.x (Update matplotlibrc urls)
* :ghpull:`25000`: Update matplotlibrc urls
* :ghpull:`24977`: Backport PR #24970 on branch v3.7.x (FIX: Handle uint8 indices properly for colormap lookups)
* :ghpull:`24970`: FIX: Handle uint8 indices properly for colormap lookups
* :ghpull:`24975`: Backport PR #24971 on branch v3.7.x (FIX: adjust_bbox should not modify layout engine)
* :ghpull:`24974`: Backport PR #24973 on branch v3.7.x (MNT: Fix double % signs in matplotlibrc)
* :ghpull:`24966`: Backport PR #24965 on branch v3.7.x (Remove additional deprecations from 3.5)
* :ghpull:`24971`: FIX: adjust_bbox should not modify layout engine
* :ghpull:`24973`: MNT: Fix double % signs in matplotlibrc
* :ghpull:`24965`: Remove additional deprecations from 3.5
* :ghpull:`24963`: Backport PR #24912 on branch v3.7.x (Remove contour warning for "no-valid-levels".)
* :ghpull:`24962`: Backport PR #24957 on branch v3.7.x (DOC: Enable Opensearch)
* :ghpull:`24961`: Backport PR #24948 on branch v3.7.x (Remove remaining deprecations from 3.5)
* :ghpull:`24959`: Backport PR #24254 on branch v3.7.x (Expire deprecations in widgets and keyword only arguments for Selectors)
* :ghpull:`24912`: Remove contour warning for "no-valid-levels".
* :ghpull:`24960`: Backport PR #24825 on branch v3.7.x (Allow non-default scales on polar axes)
* :ghpull:`24957`: DOC: Enable Opensearch
* :ghpull:`24948`: Remove remaining deprecations from 3.5
* :ghpull:`24825`: Allow non-default scales on polar axes
* :ghpull:`24254`: Expire deprecations in widgets and keyword only arguments for Selectors
* :ghpull:`24956`: Backport PR #24955 on branch v3.7.x (Cleanup bullseye plot example.)
* :ghpull:`24955`: Cleanup bullseye plot example.
* :ghpull:`24949`: Backport PR #24918 on branch v3.7.x (DOC: animation faster)
* :ghpull:`24947`: Auto backport of pr 24897 on v3.7.x
* :ghpull:`24945`: Backport PR #24940 on branch v3.7.x ([MNT] specify which gallery sections come last)
* :ghpull:`24918`: DOC: animation faster
* :ghpull:`24917`: Backport PR #24897: DOC: Add ref for every under examples/animation
* :ghpull:`24940`: [MNT] specify which gallery sections come last
* :ghpull:`24941`: Backport PR #24655 on branch v3.7.x (Update font_manager to only use registry on Win)
* :ghpull:`24655`: Update font_manager to only use registry on Win
* :ghpull:`24937`: Backport PR #24470 on branch v3.7.x ([ENH] hatch keyword for pie + some pie documentation)
* :ghpull:`24938`: Backport PR #23390 on branch v3.7.x (FIX: colorbar contour with log norm should default to log locator and formatter...)
* :ghpull:`24935`: Backport PR #24934 on branch v3.7.x (Swap ipython directives for code-block directives)
* :ghpull:`24470`: [ENH] hatch keyword for pie + some pie documentation
* :ghpull:`24933`: Backport PR #24924 on branch v3.7.x (Fix toggling layout engines)
* :ghpull:`24934`: Swap ipython directives for code-block directives
* :ghpull:`24931`: Backport PR #24783 on branch v3.7.x (inset locator fix with tests added)
* :ghpull:`24924`: Fix toggling layout engines
* :ghpull:`24928`: Backport PR #24927 on branch v3.7.x (DOC: Remove space after directive name, before double-colon)
* :ghpull:`24926`: Backport PR #24925 on branch v3.7.x (DOC: Improve documentation for set_loglevel)
* :ghpull:`24925`: DOC: Improve documentation for set_loglevel
* :ghpull:`24922`: Backport PR #24921 on branch v3.7.x (Pin sphinx != 6.1.2)
* :ghpull:`24921`: Pin sphinx != 6.1.2
* :ghpull:`24911`: Backport PR #24904 on branch v3.7.x (Deprecate AxisArtistHelpers with inconsistent loc/nth_coord.)
* :ghpull:`24897`: DOC: Add ref for every under examples/animation
* :ghpull:`24904`: Deprecate AxisArtistHelpers with inconsistent loc/nth_coord.
* :ghpull:`22314`: Add a helper to generate xy coordinates for AxisArtistHelper.
* :ghpull:`24841`: changed method in animation tutorial table of methods
* :ghpull:`24902`: Remove provisional note from pyplot.subplot_mosaic
* :ghpull:`24891`: DOC: mark mosaic as no longer provisional
* :ghpull:`24889`: Harmonize exceptions for unknown keyword arguments.
* :ghpull:`24085`: Set facecolor of FilledArrow axisline style and fix tight layout
* :ghpull:`19743`: ENH: allow fig.legend outside axes...
* :ghpull:`24887`: [MNT] Bump NumPy to 1.20
* :ghpull:`24896`: changed contribute docs link to writing docs
* :ghpull:`24894`: DOC: explain clipbox a bit better
* :ghpull:`24864`: Deprecate BrokenBarHCollection.
* :ghpull:`24869`: Skip displaying pan/zoom navigate mode in toolbar.
* :ghpull:`24892`: FIX: error in formatting in error string in redirect extension
* :ghpull:`24895`: add new & improved doc notices to what's new
* :ghpull:`24888`: update install instructions for conda
* :ghpull:`24886`: CI: rotate the circleci deploy key
* :ghpull:`24879`: Document "." as a filled marker.
* :ghpull:`24870`: Better default bool contour levels.
* :ghpull:`24786`: Increase a few test tolerances on some arches
* :ghpull:`24863`: Add parameter doc to PolarTransform
* :ghpull:`24845`: Fix toggling of MultiCursor.{horizOn,vertOn}
* :ghpull:`24862`: Fix argument checking in ``Axes3D.quiver``
* :ghpull:`24868`: [pre-commit.ci] pre-commit autoupdate
* :ghpull:`24840`: Simplify/robustify segment-point distance calculation.
* :ghpull:`24850`: Improve PolarAffine docstring
* :ghpull:`24851`: Variable rename t > theta
* :ghpull:`24763`: Allow polar scales where zero is not in valid interval
* :ghpull:`24846`: Promote pending cm deprecations to full deprecations
* :ghpull:`24848`: ``Collection.set_linestyle``: remove redundant string handling
* :ghpull:`24839`: Move geo/polar projections to their own pages
* :ghpull:`24727`: Handle argument "facecolors=None" correctly in plot_surface()
* :ghpull:`24847`: Avoid extra copy initializing empty Affine2D
* :ghpull:`24837`: DOC: Replace .format by f-strings in examples
* :ghpull:`24604`: Enh/extend mosaic kwargs
* :ghpull:`24131`: Deprecate attributes and expire deprecation in animation
* :ghpull:`23457`: Add blitting support to button widgets
* :ghpull:`24832`: [MNT] Improve variable naming in bar
* :ghpull:`24829`: Simplify shape-checking in QuadMesh.set_array.
* :ghpull:`24835`: Delay nightly wheel builds by 2 hours
* :ghpull:`24831`: [Doc] Fix ndarray-links for arguments
* :ghpull:`24824`: Fix incorrect method in doc
* :ghpull:`24826`: space in version added for reverse in legend
* :ghpull:`24819`: Bump pypa/cibuildwheel from 2.11.3 to 2.11.4
* :ghpull:`24811`: removed casting handles to list in legend
* :ghpull:`24759`: Reverse legend
* :ghpull:`24465`: Reparametrize offsetbox calculations in terms of bboxes.
* :ghpull:`22316`: Arbitrary figure customization hooks.
* :ghpull:`22329`: Enforce that Line data modifications are sequences
* :ghpull:`24730`: Data access API for rcParams
* :ghpull:`24699`: Implement nested four-level TeX cache
* :ghpull:`24752`: DOC: Make event handling table scrollable
* :ghpull:`24637`: Fixes #20044 pass AnnotationBbox to renderer
* :ghpull:`24810`: Don't modify dictionary input to widgets
* :ghpull:`24769`: Improve matplotlib.axes documentation
* :ghpull:`24806`: Deprecate 'x' argument for widgets.TextBox.begin_typing
* :ghpull:`24293`: Handle rasterization start & stop only from Artist
* :ghpull:`24768`: Fix/zorder rasterization
* :ghpull:`24474`: Use scatter for check boxes and set facecolors correctly in check boxes and radio buttons
* :ghpull:`24262`: Fix issue with space allocated for single tick that should not be there
* :ghpull:`24780`: Update environment.yml
* :ghpull:`23576`: Soft deprecate the textpath module (import from text instead)
* :ghpull:`24750`: Fix deprecations of \*Cursor widget event handlers
* :ghpull:`24757`: Allow using masked in ``set_offsets``
* :ghpull:`21661`: Fix plot directive with func calls
* :ghpull:`24803`: Correct type in docstring of zorder for streamplot and LineCollection
* :ghpull:`24801`: Correct docstring of RangeSlider.on_changed
* :ghpull:`24802`: Correct docstring of CheckButtons.get_status
* :ghpull:`24758`: MNT: Simplify code related to masked arrays
* :ghpull:`24756`: DOC: Simplify some table markup
* :ghpull:`24795`: DOC: Fix duplicate redirect
* :ghpull:`24782`: DOC: update typos and grammar errors
* :ghpull:`24794`: Update README.md
* :ghpull:`24071`: Deprecate undefined label_mode to Grid
* :ghpull:`24724`: Run delvewheel on Windows for wheels
* :ghpull:`24538`: [Doc] Document legend_handles and legend_handlers
* :ghpull:`24751`: DOC: Update Artist inheritance diagram
* :ghpull:`24761`: Don't set the never-used Line2D._contains in set_picker.
* :ghpull:`24760`: Remove unused dicts from backend_cairo.
* :ghpull:`24736`: DOC: simplify CheckButton example
* :ghpull:`22700`: MAINT: Move docstring of ``LogLocator`` to class
* :ghpull:`19763`: Remove visibility changes in draw for \*Cursor widgets
* :ghpull:`23473`: Separately track modifier keys for mouse events.
* :ghpull:`24748`: DOC: remove research notice
* :ghpull:`24734`: Support masked dates
* :ghpull:`24737`: MNT: make fig.colorbar(..., ax=INPUT) even more forgiving
* :ghpull:`24120`: don't try to start a new event loop in WebAgg when in an ipykernel
* :ghpull:`24362`: Allow bool-like values for sharex/sharey
* :ghpull:`24740`: Minor redundancy cleanup of code which sets 3D aspect 3D
* :ghpull:`22273`: Improve inheritance diagrams
* :ghpull:`24668`: Add test for remaining axis options
* :ghpull:`9598`: ENH: rely on non-rectangular patch paths rather than bboxes for legend auto-placing (fix #9580)
* :ghpull:`22920`: Mnt deprecate mlab
* :ghpull:`24408`: Fix: restore make_axes to accept a tuple of axes
* :ghpull:`24731`: DOC: Post warnings as reviews on PRs
* :ghpull:`24652`: Offsetbox default arguments
* :ghpull:`24720`: FIX: be more forgiving in default draw wrapper
* :ghpull:`24719`: Remove quotes from EngFormatter.format_eng example
* :ghpull:`24718`: Remove refresh function from polar ThetaLocator
* :ghpull:`24710`: Drop support for Qt<5.10.
* :ghpull:`24509`: Factor out & improve accuracy of derivatives calculations in axisartist.
* :ghpull:`19591`: reverse order in which stackplot elements are added to axes
* :ghpull:`24367`: STY: Update macosx zoom rect styling
* :ghpull:`24706`: Bump pypa/cibuildwheel from 2.11.2 to 2.11.3
* :ghpull:`24705`: Cleanup a few examples.
* :ghpull:`21096`: FIX: improve symlog ticker
* :ghpull:`24498`: DOC: Update multiple category bar chart examples
* :ghpull:`24688`: Deprecate quiver_doc and barbs_doc class members
* :ghpull:`24526`: [Doc] Fix spelling and grammar in tutorials
* :ghpull:`24675`: TST: set style in mpl_toolkits to ease later transition
* :ghpull:`24484`: Artist's draw method prevents rasterization by default
* :ghpull:`24667`: Test scroll zoom bbox update
* :ghpull:`24662`: Doc/git force
* :ghpull:`24664`: Deprecate offsetbox.bbox_artist
* :ghpull:`24670`: Tiny capitalization fix.
* :ghpull:`24596`: ENH: Add ellipse class for annotation box styles
* :ghpull:`24249`: Add legend tests for 3D plots
* :ghpull:`24627`: MNT: when clearing an Axes via clear/cla fully detach children
* :ghpull:`24653`: Directly call _long_axis()._set_axes_scale in Colorbar.
* :ghpull:`24640`: Small TransformWrapper cleanups.
* :ghpull:`24528`: BUG: Warn when an existing layout manager changes to tight layout
* :ghpull:`24635`: Remove unneeded _update_transScale calls in _init_axis.
* :ghpull:`24641`: Fix that font files never pass the test on Win
* :ghpull:`24522`: Use pybind11 for tri module
* :ghpull:`24603`: Shorten the definition of sawtooth boxstyle.
* :ghpull:`24630`: Improve error message for gridspec when the index is not an integer.
* :ghpull:`24634`: Init axes._children early enough to avoid need for some getattr calls.
* :ghpull:`24629`: Doc/gitwash redirects
* :ghpull:`24624`: Expire FancyBboxPatch deprecations.
* :ghpull:`24619`: ENH: Allow RGB(A) arrays for pcolormesh
* :ghpull:`23588`: Refactoring gitwash
* :ghpull:`21549`: Unifying the Figure getter/setter interface to match its constructor
* :ghpull:`24582`: Shorten demo_axes_grid example.
* :ghpull:`24577`: Fold _set_ticklabels into set_ticklabels.
* :ghpull:`24581`: Simplify implementation of _is_sorted.
* :ghpull:`24575`: Use std::isnan and fix compiler warning
* :ghpull:`24570`: FIX: VPacker and HPacker bottom/top alignment
* :ghpull:`23812`: Ci add codeql
* :ghpull:`24556`: Fix incorrect window_extent of AxesImage
* :ghpull:`24566`: Improve argument checking for set_xticks().
* :ghpull:`24544`: DOC: Add links to supported file formats in animations tutorial
* :ghpull:`24511`: Add test for mutating input arrays #8990
* :ghpull:`24558`: In mplot3d, fix a doc typo and autogen zaxis_inverted.
* :ghpull:`24555`: ENH: Add warning for SymLogScale when values in linear scale range
* :ghpull:`23417`: Consistently set label on axis with units
* :ghpull:`24542`: DOC: Clarify supported animation formats in animation tutorial
* :ghpull:`23685`: Add mathtext support for ``\middle`` and correct rendering of ``\|``
* :ghpull:`24539`: Fix misnamed api changes entry.
* :ghpull:`23692`: Add ``Axes.get_tick_params()`` method.
* :ghpull:`24132`: CenteredNorm changes
* :ghpull:`24529`: Transform ParasiteAxesBase._update_viewlim into standard callback.
* :ghpull:`24304`: Simplify some patches path definitions.
* :ghpull:`24431`: FIX: Support passing one alpha per event sequence to eventplot()
* :ghpull:`24527`: Fix testing of whether backends use the new pyplot_show API.
* :ghpull:`24537`: Fix triage tool due to test reorganization
* :ghpull:`21831`: FIX: pre-composite animation frames to white background
* :ghpull:`24205`: Plot directive: delegate file handling to Sphinx
* :ghpull:`24274`: Animation Tutorial
* :ghpull:`24519`: MNT: remove unused arguments to private methods and minor doc fixes
* :ghpull:`24525`: [Doc] Fix spelling and grammar in examples
* :ghpull:`24523`: [Doc] fix more spelling and grammar
* :ghpull:`24218`: Document what pyplot expects from a backend.
* :ghpull:`24513`: Modernize a bit floating_axes tests.
* :ghpull:`24491`: Make Path3DCollection store indexed offset, and only apply z-ordered offset during draw
* :ghpull:`24500`: DOC: Removed matplotlib from mission statement title
* :ghpull:`24490`: DOC: Remove text rotation example
* :ghpull:`24487`: Update tests to run with 3.11 (not rc)
* :ghpull:`24439`: Remove custom polar behaviour in LogLocator
* :ghpull:`24461`: Shorten and explain more calculations in axes_divider.
* :ghpull:`24472`: [DOC] removed flake8 from PR template
* :ghpull:`24467`: [DOC] swapped params in fig_compare_error msg
* :ghpull:`24455`: Draw RadioButtons using scatter to ensure circular buttons.
* :ghpull:`24462`: Don't pass unused xdescent to _get_packed_offsets.
* :ghpull:`24446`: Remove axis() manual argument parsing.
* :ghpull:`24334`: ENH: Check labels arg when kwargs passed in Axis.set_ticks()
* :ghpull:`24430`: MNT: Issue a warning instead of logging if RGB(A) passed to scatter(..., c)
* :ghpull:`24397`: Simplify appveyor to only use conda
* :ghpull:`24447`: Factor out error generation for function calls with wrong nargs.
* :ghpull:`24441`: DOC: Fix example for what's new imshow so it isn't cut off or crowded.
* :ghpull:`24443`: Add valid values to ``get_*axis_transform`` docstring
* :ghpull:`24440`: DOC: Fix colorbar what's new entry so it isn't cut off.
* :ghpull:`23787`: Use pybind11 for C/C++ extensions
* :ghpull:`24247`: Split toolkit tests into their toolkits
* :ghpull:`24432`: DOC: Fix What's New entry for bar_label() formatting.
* :ghpull:`23101`: Move show() to somewhere naturally inheritable / document what pyplot expects from a backend.
* :ghpull:`24215`: Add :shows-source-link: option to Sphinx plot directive
* :ghpull:`24423`: Tighten the Qt binding selection docs.
* :ghpull:`24403`: Use ``repr`` in error message Addresses #21959
* :ghpull:`24415`: made f2tfont error message explicit that it needs path to file
* :ghpull:`24329`: Kill FontconfigPatternParser.
* :ghpull:`23267`: Add location keyword argument to Colorbar
* :ghpull:`24375`: DOC: Group pyplot plotting commands
* :ghpull:`24307`: DOC: Organize Axes3D methods into sections
* :ghpull:`22230`: FIX: add support for imshow extent to have units
* :ghpull:`24252`: Change default rotation mode for 3D labels to 'anchor'
* :ghpull:`24356`: Expire QuadMesh old signature deprecation
* :ghpull:`24355`: Expire unused positional parameters in canvas subclasses
* :ghpull:`24257`: Load style files from third-party packages.
* :ghpull:`24279`: Cleanup BboxImage example.
* :ghpull:`24342`: Use HTML5 for webagg files
* :ghpull:`24339`: DOC: Minor cleanup in "Writing documentation"
* :ghpull:`24338`: DOC: Group pyplot commands by category
* :ghpull:`24314`: Minor improvements to Annotations Tutorial
* :ghpull:`23914`: Add shading of Poly3DCollection
* :ghpull:`24322`: GOV: change security reporting to use tidelift
* :ghpull:`24305`: Unify logic of ConnectionStyle._Base.{_clip,_shrink}.
* :ghpull:`24303`: Simplify generate_fontconfig_pattern.
* :ghpull:`24319`: Bump mamba-org/provision-with-micromamba from 13 to 14
* :ghpull:`24239`: Fix mathtext rendering of ``\|`` and sizing of ``|`` and ``\|``
* :ghpull:`23606`: added offset section & restructured annotations tutorial
* :ghpull:`24125`: Expire miscellaneous deprecations from 3.5
* :ghpull:`24306`: Remove unnecessary/replaceable explicit str calls.
* :ghpull:`24295`: Remove unnecessary np.{,as}array / astype calls.
* :ghpull:`24302`: MNT: Remove redundant int after round
* :ghpull:`24290`: Cleanup Barbs._find_tails.
* :ghpull:`24298`: List all the places to update when adding a dependency.
* :ghpull:`24289`: Cleanup image_zcoord example.
* :ghpull:`23865`: Add test and example for VBoxDivider
* :ghpull:`24287`:  Simplifying glyph stream logic in ps backend
* :ghpull:`24291`: Rely on builtin round() instead of manual rounding.
* :ghpull:`24062`: Replaced std::random_shuffle with std::shuffle in tri
* :ghpull:`24278`: Use oldest-supported-numpy for build
* :ghpull:`24161`: Versioning directives policy
* :ghpull:`24013`: Deprecate matplotlib.tri.* submodules
* :ghpull:`24031`: Add rcParams for 3D pane color
* :ghpull:`24220`: Simplify and tighten parse_fontconfig_pattern.
* :ghpull:`24251`: Expire deprecation for ``auto_add_to_figure=True`` in ``Axes3D``
* :ghpull:`24160`: sample versioning directives, empty + description
* :ghpull:`24253`: Expire deprecation of grid argument name
* :ghpull:`14471`: FIX: don't close figures if switch_backend is a no-op
* :ghpull:`24240`: Deprecate unit_cube-related methods in Axes3D
* :ghpull:`24244`: Clarify that z must be finite for tricountour(f)
* :ghpull:`23536`: Improve mpl_toolkit documentation
* :ghpull:`24243`: Improve documentation for ticker
* :ghpull:`24189`: Do not pass gridspec_kw to inner layouts in subplot_mosaic
* :ghpull:`24242`: Add information about environment variables in matplotlib.__doc__
* :ghpull:`24241`: Small animation docs/style fixes.
* :ghpull:`24236`: DOC: Mark SubplotBase removals in code style
* :ghpull:`24141`: Set figure options dynamically
* :ghpull:`23796`: Remove useless semicolons in "Introductory / Basic Usage" tutorial
* :ghpull:`23573`: Merge SubplotBase into AxesBase.
* :ghpull:`23931`: Raise ValueError on negative number inputs for set_aspect
* :ghpull:`24065`: Fixed the positioning of cursor in Textbox: no approximation
* :ghpull:`24122`: Add textcolor to legend based on labelcolor string
* :ghpull:`24182`: MNT: Remove redundant method, fix signature and add doc-string to ``draw_tex``
* :ghpull:`24224`: Deprecate Julian date-related functions and constant
* :ghpull:`24196`: MNT: Update pre-commit hooks
* :ghpull:`24221`: Deprecate BufferRegion.to_string{,_argb}.
* :ghpull:`23683`: Simplify/add pyparsing error messages on mathtext/fontconfig errors.
* :ghpull:`24210`: Small cleanups to axislines docs.
* :ghpull:`24213`: Cleanup make_compound_path_from_poly doc, example.
* :ghpull:`24208`: Deprecate backend_webagg.ServerThread.
* :ghpull:`24207`: Recommend multiple_yaxis_with_spines over parasite axes.
* :ghpull:`24156`: Automatically update rebase label
* :ghpull:`24198`: Deprecate unused backend_ps.{PsBackendHelper,ps_backend_helper}.
* :ghpull:`24129`: Expire cursor-related deprecations
* :ghpull:`24179`: MNT: Refactor ``Renderer.get_text_width_height_descent``
* :ghpull:`24191`: BLD: be more cautious about checking editable mode
* :ghpull:`24000`: Generalize validation that pyplot commands are documented
* :ghpull:`24144`: Deprecate some label-related attributes on ContourLabeler.
* :ghpull:`24162`: windows doc build parity
* :ghpull:`24102`: Simplest pyproject.toml containing build-system only
* :ghpull:`24091`: MNT: Clean up code in SecondaryAxis
* :ghpull:`24140`: Replace ClabelText by set_transform_rotates_text.
* :ghpull:`24143`: Add QuadContourSet.remove.
* :ghpull:`24138`: [DOC] Fix some documentation typos
* :ghpull:`24128`: Expire deprecations in dates and ticker
* :ghpull:`23907`: Inherit OffsetBox.get_window_extent.
* :ghpull:`23449`: Add pan and zoom toolbar handling to 3D Axes (Replaces PR#22614)
* :ghpull:`24126`: Bump version when invalid hatches error
* :ghpull:`23874`: Expire parameter renaming and deletion and attribute privatization from 3.5
* :ghpull:`23592`: Polar errcaps
* :ghpull:`24083`: Enable interactive figure resizing for webagg and nbagg backends
* :ghpull:`24110`: test readme rendering
* :ghpull:`24067`: README.rst to README.md
* :ghpull:`23702`: Get Mathtext ``\times`` symbol from ``cmsy10`` when using ``cmr10``.
* :ghpull:`24066`: Simplify svg font expansion logic.
* :ghpull:`23730`: [DOC]: Add grid to style sheets
* :ghpull:`24020`: [DOC]: adding a grid to the style sheet reference.
* :ghpull:`23579`: Remove direct manipulation of HostAxes.parasites by end users.
* :ghpull:`23553`: Add tests for ImageGrid
* :ghpull:`23918`: Merge v3.6.x branch to main
* :ghpull:`23902`:  Add test and improve examples for mpl_toolkits
* :ghpull:`23950`: DOC: Don't import doctest because we're not using it
* :ghpull:`21006`: Rotate errorbar caps in polar plots
* :ghpull:`23870`: Implement Sphinx-Gallery's ``make html-noplot``
* :ghpull:`23905`: made explicit that install link is install docs in readme
* :ghpull:`23824`: Deprecate draw_gouraud_triangle
* :ghpull:`23913`: Add draggable as param to Legend init
* :ghpull:`23896`: Inline AnchoredOffsetBox._update_offset_func.
* :ghpull:`23889`: Update image tutorial.
* :ghpull:`23861`: Move axes_grid tests to axes_grid1
* :ghpull:`23254`: Add PathCollection test for ps backend
* :ghpull:`23542`: Add even more mplot3d tests
* :ghpull:`23698`: Fix bug in ``Axes.bar_label(label_type='center')`` for non-linear scales.
* :ghpull:`23767`: DEV: add flake8-force plugin
* :ghpull:`23835`: Fix version switcher links
* :ghpull:`23832`: Improve skip message for image comparison tests
* :ghpull:`23690`: Add new-style string formatting option and callable option to ``fmt`` in ``Axes.bar_label()``.
* :ghpull:`23804`: Fix TexManager's support for ``openin_any = p``
* :ghpull:`23737`: Update grammar
* :ghpull:`23552`: Provide ``adjustable='box'`` to 3D axes aspect ratio setting
* :ghpull:`23769`: Bump mamba-org/provision-with-micromamba from 12 to 13
* :ghpull:`23590`: Changing bar examples to tea and coffee
* :ghpull:`21253`: Fix: axis, ticks are set to defaults fontsize after ax.clear()
* :ghpull:`21968`: Changed fstring to make error clearer
* :ghpull:`22614`: ENH: Add pan and zoom toolbar handling to 3D Axes
* :ghpull:`21562`: Add a test for Hexbin Linear

Issues (120):

* :ghissue:`25176`: [Bug]: Colorbar is displaced when saving as .eps with bbox_inches='tight'
* :ghissue:`25075`: [Bug]: Widget blitting broken when saving as PDF
* :ghissue:`25181`: unavoidable warnings in nbagg on ``plt.close``
* :ghissue:`25134`: [Doc]: pyplot.boxplot whisker length wrong docs
* :ghissue:`24395`: Any resizing of the plot after plt.show results in an error when closing the window
* :ghissue:`25107`: [Doc]: annotated_cursor example seems broken
* :ghissue:`25124`: [Bug]: ax.plot(x,y) disappears after changing y_scale
* :ghissue:`8278`: FuncAnimation with generator defaults to arbitrary save_count=100
* :ghissue:`22765`: Document distutil vs setuptools issues or fix usage
* :ghissue:`25077`: [Bug]: Setting norm with existing colorbar fails with 3.6.3
* :ghissue:`23999`: [Bug]: Annotation misplaced when rasterizing and saving as PDF
* :ghissue:`25040`: [Bug]: Request to insecure websocket endpoint is blocked by browser
* :ghissue:`24678`: [Bug]: pcolormesh doesn't allow shading = 'flat' in the option
* :ghissue:`15388`: matplotlib.collections.QuadMesh.set_array() input arg format is weird and undocumented
* :ghissue:`23779`: [ENH]: control the size of the tex cache
* :ghissue:`24583`: [ENH]: provide public API for styling radio buttons
* :ghissue:`21895`: [Bug]: slow rendering of multiple axes (time scales as 2nd power of label count)
* :ghissue:`4781`: Add API to register styles
* :ghissue:`24972`: [MNT]: UserWarning from pyparsing upon immediate import
* :ghissue:`24865`: [Bug]: NumPy 1.24 deprecation warnings
* :ghissue:`24954`: [Bug]: compressed layout setting can be forgotten on second save
* :ghissue:`23778`: [ENH]: Allow override of contour level autoscaling
* :ghissue:`20203`: contour edge case with all data below levels and a surrounding field of zeros
* :ghissue:`12803`: pcolormesh in log polar coordinates
* :ghissue:`24383`: log scale and polar broken
* :ghissue:`22847`: [Bug]: Cannot toggle set_tight_layout
* :ghissue:`23646`: [Bug]: matplotlib.set_loglevel() adds a console handler
* :ghissue:`24673`: [Doc]: animation examples show controls; source does not reproduce them
* :ghissue:`7617`: set_ylabel does not work as expected with SubplotZero
* :ghissue:`13023`: constrained_layout support for figure.legend
* :ghissue:`15973`: span_where fails with timeseries on the x-axis
* :ghissue:`24867`: [Bug]: controlling text on toolbar in wx
* :ghissue:`24421`: [Doc]: change to install from conda forge
* :ghissue:`24890`: [Bug]: Clipping mask can shift in PDF and SVG file outputs when Bbox is adjusted
* :ghissue:`23849`: [Bug]: The point marker is not actually unfilled
* :ghissue:`24321`: [ENH]: Auto-detect bool arrays passed to contour()?
* :ghissue:`24842`: axes3d.quiver() fails when providing args to Line3DCollection
* :ghissue:`24093`: [Bug]: CenteredNorm gets stuck in infinite recursion when given all zeros
* :ghissue:`24571`: [ENH]: gridspec_mosaic
* :ghissue:`24815`: [TST] Upcoming dependency test failures
* :ghissue:`24712`: [ENH]: Reverse legend
* :ghissue:`22308`: [Bug] set_3d_properties type error in Matplotlib 3.5.1
* :ghissue:`24741`: [Doc]: tables in "notes" cut off content
* :ghissue:`20044`: AnnotationBbox gid not passed to renderer
* :ghissue:`24762`: [Doc]: Development workflow doc has lots of typos and clunky sentences
* :ghissue:`24235`: [Bug]: pcolormesh(rasterized=True) conflicts with set_rasterization_zorder()
* :ghissue:`24471`: [Bug]: CheckBoxes should be square, not rectangular
* :ghissue:`18804`: bugged pads on savefig
* :ghissue:`20656`: Sphinx extension plot_directive not able to detect function
* :ghissue:`24704`: [Bug]: ImportError: DLL load failed on Windows
* :ghissue:`20639`: document Legend.legendHandles
* :ghissue:`19633`: Multicursor disappears when not moving on nbagg with useblit=False + burns CPU
* :ghissue:`24717`: Update Research Notice on README.md
* :ghissue:`22754`: [Bug]: It is recommended for you  to run autogen before configuring freetype
* :ghissue:`24349`: [Bug]: sharex and sharey don't accept 0 and 1 as bool values
* :ghissue:`20577`: Using ``legend(labelcolor="markerfacecolor")`` with a scatter plot throws an error
* :ghissue:`24424`: [Doc]: Inheritance diagrams
* :ghissue:`9580`: Broken legend auto-position with step*-type histograms
* :ghissue:`22176`: [MNT]: Write a bot to post doc build issues
* :ghissue:`24623`: [Bug]: ``offsetbox`` classes have optional arguments that are really not optional
* :ghissue:`24693`: [MNT]: Update minver policy re: GUI toolkits
* :ghissue:`23566`: [ENH]: Z-axis/3D support for Figure options
* :ghissue:`23777`: [ENH] Interactive Zoom Rectangle Color Review for MACOSX backend
* :ghissue:`24676`: [Doc]: quiver_doc etc leads to documentation of the documentation string
* :ghissue:`24568`: [ENH]: Ellipse annotation
* :ghissue:`6982`: cla(), clf() should unset the ``.axes`` and ``.figure`` attributes of deparented artists
* :ghissue:`11227`: fig.set_dpi() does not set the dpi correctly
* :ghissue:`24418`: [ENH]: rgp or rgba option for pyplot pcolormesh and/or pcolor
* :ghissue:`22236`: [Bug]: integer colours for pcolorfast / quadmesh
* :ghissue:`4277`: RGB not supported in pcolormesh
* :ghissue:`23155`: [ENH]: do_3d_projection could restore original verts order after draw() finishes
* :ghissue:`24386`: [Bug]: ``align`` in ``HPacker`` is reversed
* :ghissue:`23803`: Static code analysis
* :ghissue:`8990`: Surprising behaviour of mutating input arrays to Axes.plot vs Axes3D.plot
* :ghissue:`24550`: [ENH]: Warn when a SymLogScale receives values that are all in the linear regime
* :ghissue:`23416`: [Bug]: Inconsistent y-axis unit label with plot/scatter
* :ghissue:`23603`: [MNT]: Only a subset of attributes set via ``Axes.tick_params()`` are accessible via public methods and attributes
* :ghissue:`13858`: matplotlib.sphinxext.plot_directive generates incorrect links when using dirhtml builder
* :ghissue:`19376`: eventplot: allow a list of alpha channels as in the case with colors
* :ghissue:`24508`: [Bug]: Re-organization of mpl_toolkits tests broke tools/triage_tests.py
* :ghissue:`19040`: v3.3.0 Regression, Animation draws artists multiple times.
* :ghissue:`12324`: DOC: Write a unified backend doc
* :ghissue:`24464`: Issue with legend labelcolor='linecolor' for errorbar plots
* :ghissue:`24273`: [ENH]: Axes.set_xticks/Axis.set_ticks only validates kwargs if ticklabels are set, but they should
* :ghissue:`24454`: [Bug]: "import matplotlib.pyplot" gives ModuleNotFoundError
* :ghissue:`24394`: [TST]: Appveyor Qt tests failing
* :ghissue:`21959`: [ENH]: Use ``repr`` instead of ``str`` in the error message
* :ghissue:`22676`: [ENH]: Colorbar should support location kwarg that sets both orientation and ticklocation
* :ghissue:`23901`: [Doc]: add summary table to Axes3D similar to Axes
* :ghissue:`22105`: [Bug]: imshow extents can't have units?
* :ghissue:`21878`: [MNT]: make axis labels of 3d axis anchor-rotate
* :ghissue:`17978`: Document how to distribute style files in python packages
* :ghissue:`23965`: Simplify glyph stream logic in ps backend
* :ghissue:`19509`: Adding lightsource when plotting Poly3DCollection
* :ghissue:`17523`: Unclear if no gallery argument for doc builds works
* :ghissue:`23250`: [Bug]: Incorrect mathtext rendering of ``r"$\|$"`` with default (dejavu) math fontfamily
* :ghissue:`24010`: c++17 removed random_shuffle
* :ghissue:`20424`: function shadowing their own definition modules
* :ghissue:`20781`: Make the pane color in 3d plots configurable
* :ghissue:`14426`: Existing FigureCanvasQT objects destroyed by call to plt.figure
* :ghissue:`5908`: Unclear Documentation ticker class
* :ghissue:`24099`: [Bug]: Error using width_ratios with nested mosaic in subplot_mosaic()
* :ghissue:`6893`: List environment variables in matplotlib.__doc__
* :ghissue:`11445`: The axes module structure
* :ghissue:`23847`: [Bug]: set_aspect with negative argument leads to infinite loop
* :ghissue:`24136`: [Doc]: document ``julian2num`` and ``num2julian``?
* :ghissue:`5332`: QuadContourSet lacks remove method
* :ghissue:`110`: pan and zoom are broken for mplot3d
* :ghissue:`441`: Polar plot error bars don't rotate with angle
* :ghissue:`24064`: Convert readme.rst to readme.md
* :ghissue:`10029`: \times in minor ticklabels not recognized due to \mathdefault
* :ghissue:`24080`: verify quoting method in svg backend for font names
* :ghissue:`23601`: [Doc]: add gridlines to style sheet reference
* :ghissue:`24075`: [ENH]: Resizing the figure with webagg backend by dragging the corner
* :ghissue:`23352`: [Doc]: bar examples should probably not have "score by ... gender" in them...
* :ghissue:`23819`: [MNT]: Make draw_gouraud_triangle optional
* :ghissue:`9181`: legend draggable as keyword
* :ghissue:`23688`: [Bug]: ``Axes.bar_label()`` on log scale does not center the label.
* :ghissue:`23689`: [ENH]: Add f-string formatting to labels in ``Axes.bar_label()``
* :ghissue:`23718`: [Bug]: Installing from source fails during Freetype compilation with spaces in working directory filepath
